# circular build dependency on requests-download and testpath
%bcond_without tests

%define pypi_name flit

Name:		python-%{pypi_name}
Version:	3.7.1
Release:	%mkrel 1
Summary:	Simplified packaging of Python modules

# ./flit/log.py under ASL 2.0 license
# ./flit/upload.py under PSF license
License:	BSD and ASL 2.0 and Python
Group:      Development/Python
URL:		https://flit.readthedocs.io/en/latest/
Source0:	%{pypi_source}

# For the tests
Source1:	https://pypi.org/pypi?%3Aaction=list_classifiers#/classifiers.lst

BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
BuildRequires:	pyproject-rpm-macros

# Runtime deps needed to build self
BuildRequires:	python3-tomli

%if %{with tests}
# Runtime deps, others
BuildRequires:	python3-requests
BuildRequires:	python3-docutils
BuildRequires:	python3-pygments
BuildRequires:	python3-tomli-w

# Test deps
BuildRequires:	python3-pytest
BuildRequires:	python3-responses

# Test deps that require flit to build:
BuildRequires:	python3-testpath
BuildRequires:	python3-requests-download
%endif

%global _description %{expand:
Flit is a simple way to put Python packages and modules on PyPI.

Flit only creates packages in the new 'wheel' format. People using older
versions of pip (<1.5) or easy_install will not be able to install them.

Flit packages a single importable module or package at a time, using the import
name as the name on PyPI. All sub-packages and data files within a package are
included automatically.

Flit requires Python 3, but you can use it to distribute modules for Python 2,
so long as they can be imported on Python 3.}

%description %_description


%package -n python3-%{pypi_name}
Summary:	%{summary}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:	python3-%{pypi_name}-core = %{version}-%{release}

# https://pypi.python.org/pypi/tornado
# ./flit/log.py unknown version
Provides:	bundled(python3dist(tornado))

# soft dependency: (WARNING) Cannot analyze code. Pygments package not found.
Recommends:	python3-pygments

%description -n python3-%{pypi_name} %_description


%package -n python3-%{pypi_name}-core
Group:		Development/Python
Summary:	PEP 517 build backend for packages using Flit
%{?python_provide:%python_provide python3-%{pypi_name}-core}
Conflicts:	python3-%{pypi_name} < 2.1.0-2
# We manually specify this, because it's bundled upstream and not in the metadata
Requires:       python3-tomli

%description -n python3-%{pypi_name}-core
This provides a PEP 517 build backend for packages using Flit.
The only public interface is the API specified by PEP 517,
at flit_core.buildapi.


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Remove vendored tomli that flit_core includes to solve the circular dependency.
# (flit_core requires tomli, but flit_core is needed to build tomli).
# We don't use this, as python3-tomli already has its own bootstrap bcond
# to build without flit_core.
#
# flit's tests already require tomli, so we're pulling it in at buildtime anyways.
sed -i 's|from \.vendor import tomli|import tomli|' flit_core/flit_core/config.py
rm -rf flit_core/flit_core/vendor

%build
export FLIT_NO_NETWORK=1

# first, build flit_core with self
pushd flit_core
%pyproject_wheel
popd

# build of the main flit (needs flit_core)
export PYTHONPATH=$PWD:$PWD/flit_core
%pyproject_wheel

%install
%pyproject_install

# don't ship tests in flit_core package
# if upstream decides to change the installation, it can be removed:
# https://github.com/takluyver/flit/issues/403
rm -r %{buildroot}%{python3_sitelib}/flit_core/tests/

%if %{with tests}
%check
# flit attempts to download list of classifiers from PyPI, but not if it's cached
# test_invalid_classifier fails without the list
mkdir -p fake_cache/flit
cp %{SOURCE1} fake_cache/flit
export XDG_CACHE_HOME=$PWD/fake_cache

%pytest
%endif


%files -n python3-%{pypi_name}
%license LICENSE
%doc README.rst
%{python3_sitelib}/flit-*.dist-info/
%{python3_sitelib}/flit/
%{_bindir}/flit


%files -n python3-%{pypi_name}-core
%license LICENSE
%doc flit_core/README.rst
%{python3_sitelib}/flit_core-*.dist-info/
%{python3_sitelib}/flit_core/


%changelog
* Thu Aug 11 2022 wally <wally> 3.7.1-1.mga8
+ Revision: 1876929
- enable tests as all needed pkgs should be now available

* Thu Aug 11 2022 wally <wally> 3.7.1-0.mga8
+ Revision: 1876915
- sync with cauldron version 3.7.1 (mga#30736)
- bootstrap build without tests

* Sat Nov 14 2020 guillomovitch <guillomovitch> 3.0.0-1.mga8
+ Revision: 1646151
- new version 3.0.0

* Tue Jun 09 2020 daviddavid <daviddavid> 2.3.0-1.mga8
+ Revision: 1591159
- new version: 2.3.0

* Thu Feb 20 2020 umeabot <umeabot> 2.2.0-2.mga8
+ Revision: 1546111
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1485939
- new version: 2.2.0

* Sat Dec 14 2019 daviddavid <daviddavid> 2.1.0-2.mga8
+ Revision: 1467109
- properly package flit-core and restore /usr/bin/flit (#1783610)

* Thu Dec 12 2019 daviddavid <daviddavid> 2.1.0-1.mga8
+ Revision: 1466064
- new version: 2.1.0

* Fri Sep 06 2019 wally <wally> 1.3-2.mga8
+ Revision: 1437998
- rebuild for python3.8

* Fri Apr 19 2019 wally <wally> 1.3-1.mga7
+ Revision: 1393412
- new version 1.3

* Tue Jan 08 2019 tv <tv> 0.11.4-3.mga7
+ Revision: 1352058
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.11.4-2.mga7
+ Revision: 1288906
- Mageia 7 Mass Rebuild

* Tue Aug 15 2017 philippem <philippem> 0.11.4-1.mga7
+ Revision: 1140806
- add group
- imported package python-flit

